@@ -6,8 +6,11 @@ def setup(app):
     static_path = abspath(join(dirname(__file__), '_static'))
     app.connect('builder-inited', lambda app: app.config.html_static_path.append(static_path))
 
-    #app.add_stylesheet("minipres.css")
-    app.add_javascript('minipres.js')
+    if hasattr(app, 'add_js_file'):
+        app.add_js_file('minipres.js')
+    else:
+        #app.add_stylesheet("minipres.css")
+        app.add_javascript('minipres.js')
 
     return {
         'version': '0.1',
